@@ -1,10 +1,6 @@
-import numpy as np
 from ..utils import validate_value, ITEM_TYPE, validate_response
 
 
-dfloat32 = np.dtype('>f4')
-
-
 class DocumentEmbedding():
     """Manage embedding related profile calls."""
 
